@@ -56,7 +56,7 @@
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
 
- ** Description: generates naive cgi search form for search of sisu database (pgsql sqlite)
+ ** Description: generates naive cgi search form for search of sisu database (pgsql)
 
 =end
 module  SiSU_CGI_PgSQL                                                            #% database building documents
@@ -66,17 +66,13 @@ module  SiSU_CGI_PgSQL
   class SearchPgSQL < CGI_Common
     def initialize(opt,webserv)
       @opt,@webserv=opt,webserv
+      @cX=SiSU_Screen::Ansi.new(opt.cmd).cX
       @env=SiSU_Env::InfoEnv.new('',opt)
       @sys=SiSU_Env::SystemCall.new
       @db=SiSU_Env::InfoDb.new
       get_init=SiSU_Env::GetInit.new
       @rc=get_init.sisu_yaml.rc
       @name_of={}
-      if defined? @rc['webserv'] \
-      and defined? @rc['webserv']['url_root'] \
-      and defined? @rc['webserv']['url_root'] =~/\S+/
-        @name_of[:host_url_docs]=@rc['webserv']['url_root']
-      end
       @name_of[:output_dir_structure]=if defined? @rc['output_dir_structure_by'] \
       and defined? @rc['output_dir_structure_by'] =~/(language|filetype|filename)/
         @rc['output_dir_structure_by']
@@ -89,18 +85,17 @@ module  SiSU_CGI_PgSQL
       and defined? @rc['search']['sisu']['db'] \
       and @rc['search']['sisu']['db'] =~/\S+/
         @name_of[:db]=@rc['search']['sisu']['db']
-        #@name_of[:cgi_script]=/https?:\/\/\S+?([^\/]+?)\.cgi$/.match(@rc['search']['sisu']['action'])[1]
-        @name_of[:host_url_cgi],@name_of[:cgi_script]=/(https?:\/\/\S+?)\/([^\/]+?)\.cgi$/.match(@rc['search']['sisu']['action'])[1,2]
       else
-        @name_of[:host_url_docs]=@env.url.webserv_files_from_db
-        @name_of[:db]='sisu' #breaks if not present
-        @name_of[:host_url_cgi]=@env.url.webserv_base_cgi
-        @name_of[:cgi_script]='sisu_pgsql'
+        @name_of[:db]=@env.path.stub_pwd #'sisu' #breaks if not present
         false
       end
+      @name_of[:host_url_cgi]="#{@env.url.webserv_base_cgi(@opt)}/cgi-bin"
+      @name_of[:host_url_docs]=@env.url.webserv_files_from_db(@opt)
+      @name_of[:cgi_script]=@env.url.cgi_sample_search_form_name(@opt)
+      @name_of[:user]=@db.psql.user(@opt)
       @cgi_file_name="#{Db[:name_prefix_db]}by_#{opt.dir_structure_by.to_s}_pgsql.cgi"
-      @cgi_link_name="#{@name_of[:db]}.cgi" #sisu_pgsql.cgi,
-      @image_src="#{@name_of[:host_url_docs]}/_sisu/image_sys"
+      @cgi_link_name=@name_of[:cgi_script] #sisu_pgsql.cgi,
+      @image_src="#{@env.url.webserv_base_cgi(@opt)}/_sisu/image_sys"
       @common=SiSU_CGI_SQL::CGI_Common.new(@webserv,@opt,@image_src,@env)
     end
     def pgsql
@@ -125,25 +120,69 @@ module  SiSU_CGI_PgSQL
       if FileTest.writable?('.')
         output=File.open(@cgi_file_name,'w')
         output << header0 << header1 << header_desc << header2 << f1 << buttons1 << buttons1_pgsql << buttons2 << search_request << search_statement << search_statement_common << search_query1 << @common.pages << search_query2 << @common.tail << @common.main1 << f2 << dbi_connect << @common.main2 << @common.dir_structure << @common.main3
-        a=%{        generated #{@cgi_file_name},
-            BASED ON ALREADY EXISTING directories that could potentially be used to populate postgresql db, (-D)
-        }
-        SiSU_Screen::Ansi.new(@opt.cmd,a).print_grey
-        c=case @webserv
+        puts <<-WOK
+            generated sample search form: #{@cX.green}#{@cgi_file_name}#{@cX.off}
+            default database name:     #{@cX.green}#{Db[:name_prefix]}#{@name_of[:db]}#{@cX.off} (#{@name_of[:db]})
+            db user:                   #{@cX.green}#{@name_of[:user]}#{@cX.off}
+              to modify use:           #{@cX.brown}sisu --db-pg --db-user='#{@name_of[:user]}'#{@cX.off}
+            cgi & db host on:          #{@cX.blue}#{@name_of[:host_url_cgi]}#{@cX.off}
+              to modify use:           #{@cX.brown}sisu --db-pg --webserv-search='#{@name_of[:host_url_cgi]}'#{@cX.off}
+            sisu output on:            #{@cX.blue}#{@name_of[:host_url_docs]}#{@cX.off}
+              to modify use:           #{@cX.brown}sisu --db-pg --webserv-output='#{@name_of[:host_url_docs]}'#{@cX.off}
+            cgi search form link name: #{@cX.green}#{@name_of[:cgi_script]}#{@cX.off}
+              to modify use:           #{@cX.brown}sisu --db-pg --cgi-search-form-name='#{@name_of[:cgi_script]}'#{@cX.off}
+            #{@cX.fuschia}(settings priority: command line; sisurc.yml; else defaults)#{@cX.off}
+
+            #{@cX.fuschia}BASED ON ALREADY EXISTING databases#{@cX.off} (default database name: #{@db.psql.db})
+            NOTE it is first necessary to createdb,
+            use sisu to create the tables & populate the postgresql db
+
+            the database to be used for this directory (#{@db.psql.db})
+            will have to be created manually if it does not exist:
+            using postgresql tools directly (the following may work):
+              (i) if you are not yet a postgresql user,
+                #{@cX.brown}sudo su postgres
+                  createuser -d -a #{@env.user}
+                exit#{@cX.off}
+              (ii) create the database:
+                #{@cX.brown}createdb #{@db.psql.db}#{@cX.off}
+            [for a list of existing databases try 'psql --list']"
+
+            now you can use sisu to create the database tables and populate the database with documents
+
+            sisu --pg --dropall                              # removes existing postgresql db & tables
+            sisu --pg --createall -v                         # creates postgresql db & tables
+            sisu --pg --update -v *.sst  *.ssm               # populate the db
+            sisu --sample-search-form --pg                   # creates the postgresql search form
+                                                             # this should be done after creating the db
+                                                             # to be searched
+            sisu --webrick &                                 # starts ruby webrick web server
+
+            # if necessary make the directory '/usr/lib/cgi-bin'
+            # here we copy the postgresql search form to cgi-bin
+            # (copy #{@cgi_file_name} to your cgi directory)
+            # set file permissions to 755, &
+            # make symbolic link to #{@cgi_link_name}
+        WOK
+        a=case @webserv
         when /pwd/; ''
-        else "if necessary make the directory /usr/lib/cgi-bin :
-                  sudo cp -vi #{Dir.pwd}/#{@cgi_file_name} /usr/lib/cgi-bin/.
-                  sudo chmod -v 755 /usr/lib/cgi-bin/#{@cgi_file_name}
-                  sudo ln -s /usr/lib/cgi-bin/#{@cgi_file_name} /usr/lib/cgi-bin/#{@cgi_link_name}
-                  (copy #{@cgi_file_name} to your cgi directory) set file permissions to 755, and make symbolic link to #{@cgi_link_name}"
+        else <<-WOK
+
+              sudo cp -vi #{Dir.pwd}/#{@cgi_file_name} /usr/lib/cgi-bin/.; \\
+              cd /usr/lib/cgi-bin && \\
+                sudo chmod -v 755 #{@cgi_file_name}; \\
+                sudo rm -vi #{@cgi_link_name}; \\
+                sudo ln -s #{@cgi_file_name} #{@cgi_link_name}; \\
+              cd -
+          WOK
         end
-        a=%{#{c}
-                  #{@env.webserv_base_cgi}/cgi-bin/#{@cgi_link_name}
-        }
         SiSU_Screen::Ansi.new(@opt.cmd,a).warn
-        a="postgresql db used for present directory: #{@db.psql.db}"
-        b="\n\t(to create and populate postgresql database see 'man sisu' and in particular the -D flag)\n\t[the database to be used for this directory (#{@db.psql.db}) will have to be created manually if it does not exist,\n\tsee 'sisu --help sql'\n\tif you have permission to create databases:\n\t'sisu -d --createdb'\n\tor using postgresql tools directly:\n\t'createdb #{@db.psql.db}'\n\tfor a list of existing databases try 'psql --list']"
-        SiSU_Screen::Ansi.new(@opt.cmd,a,b).txt_cyan
+        a=<<-WOK
+              #{@env.webserv_base_cgi(@opt)}/cgi-bin/#{@cgi_link_name}
+        WOK
+        SiSU_Screen::Ansi.new(@opt.cmd,a).print_blue
+        a="\n\t(to create and populate postgresql database see 'man sisu' and in particular the --pg option)\n\t[the database to be used for this directory (#{@db.psql.db}) will have to be created manually if it does not exist,\n\tusing postgresql tools directly: 'createdb #{@db.psql.db}' for a list of existing databases try 'psql --list']"
+        SiSU_Screen::Ansi.new(@opt.cmd,a).txt_grey
       else puts 'failed in attempt to write #{@cgi_file_name} to present directory,  is directory writable?'
       end
     end
@@ -158,14 +197,15 @@ module  SiSU_CGI_PgSQL
       require 'cgi'
       require 'fcgi'
       require 'dbi'
-      @stub_default="#{@name_of[:db]}"
-      @image_src="#{@name_of[:host_url_docs]}/_sisu/image_sys"
-      @hosturl_cgi="#{@name_of[:host_url_cgi]}"
-      @hosturl_files="#{@name_of[:host_url_docs]}"
-      @output_dir_structure_by="#{@name_of[:output_dir_structure]}"
-      @port="#{@db.psql.port}"
-      @db_name_prefix="#{Db[:name_prefix]}"
-      user='www-data'  # check user name for access to pg database: e.g. www-data or '#{@env.user}'
+      @stub_default='#{@name_of[:db]}'
+      @image_src='#{@image_src}'
+      @hosturl_cgi='#{@name_of[:host_url_cgi]}'
+      @hosturl_files='#{@name_of[:host_url_docs]}'
+      @output_dir_structure_by='#{@name_of[:output_dir_structure]}'
+      @port='#{@db.psql.port}'
+      @db_name_prefix='#{Db[:name_prefix]}'
+      @user='#{@name_of[:user]}'  # check user name for access to pg database: e.g. www-data or '#{@env.user}'
+      @base='#{@name_of[:host_url_cgi]}/#{@name_of[:cgi_script]}'
       WOK_SQL
     end
     def search_statement
@@ -250,7 +290,7 @@ module  SiSU_CGI_PgSQL
     def dbi_connect
       <<-'WOK_SQL'
           dbi="dbi:Pg:database=#{@db};port=#{@port}"
-          @conn=DBI.connect(dbi,user)
+          @conn=DBI.connect(dbi,@user)
       WOK_SQL
     end
   end
